==> 0.0.5.tar.gz: lib/classes/Devices/zi_device.dart <==
import '../../classes/device.dart';
import 'package:xml/xml.dart';
import '../classes.dart';

class ZiDevice extends Device {
  ZiDevice(
      {required ZiDeviceParameter deviceParameter,
      required String deviceIndex,
      required String deviceName,
      required String deviceParameterType,
      required List<InterfaceMode> supportedInterfaceModes,
      required List<Device> devices})
      : super(
            deviceParameter: deviceParameter,
            devices: devices,
            deviceParameterType: deviceParameterType,
            deviceName: deviceName,
            deviceIndex: deviceIndex,
            supportedInterfaceModes: supportedInterfaceModes);

  factory ZiDevice.fromDevice(Device d) {
    return ZiDevice(
      deviceParameter: ZiDeviceParameter.fromXML(d.deviceParameter.toXML()),
      deviceIndex: d.deviceIndex,
      deviceName: d.deviceName,
      deviceParameterType: d.deviceParameterType,
      supportedInterfaceModes: d.supportedInterfaceModes,
      devices: d.devices,
    );
  }
}

class ZiDeviceParameter extends DeviceParameter {
  ZiDeviceParameter({
    required VendorModelInfo vendorModelInfo,
    required IpAndPort ipAndPort,
    required Status status,
  }) : super(
            vendorModelInfo: vendorModelInfo,
            ipAndPort: ipAndPort,
            status: status);

  factory ZiDeviceParameter.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);

    XmlElement? vendorModelInfoElement =
        document.firstChild!.getElement("vendorModelInfo");
    XmlElement? ipAndPortElement = document.firstChild!.getElement("ipAndPort");
    XmlElement? statusElement = document.firstChild!.getElement("ziStatus");

    VendorModelInfo vendorModelInfo = vendorModelInfoElement == null
        ? VendorModelInfo(vendor: '', model: '', miscInfo: '')
        : VendorModelInfo.fromXML(vendorModelInfoElement.toXmlString());

    IpAndPort ipAndPort = IpAndPort.fromXML(ipAndPortElement!.toXmlString());
    ZiStatus status = ZiStatus.fromXML(statusElement!.toXmlString());
    return ZiDeviceParameter(
      vendorModelInfo: vendorModelInfo,
      ipAndPort: ipAndPort,
      status: status,
    );
  }

  @override
  String toXML() {
    return '''
                  <ziDeviceParameter>
                      ${ipAndPort.toXML()}
                      ${status.toXML()}
                  </ziDeviceParameter>
    '''
        .trimer;
  }
}

class ZiStatus extends Status {
  final List<Status> status;

  ZiStatus(
      {required String desc,
      required String init,
      required String ready,
      required String unknown,
      required this.status})
      : super(
            desc: desc,
            init: init,
            powerOff: "",
            ready: ready,
            unknown: unknown);

  factory ZiStatus.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    String desc = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "desc",
            orElse: orElseEmpty)
        .value;
    String init = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "init")
        .value;
    String ready = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "ready")
        .value;
    String unknown = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "unknown")
        .value;
    List<Status> status = [];
    return ZiStatus(
        desc: desc, init: init, ready: ready, unknown: unknown, status: status);
  }

  @override
  String toXML() {
    return '''
    <ziStatus desc="$desc" init="$init" ready="$ready" unknown="$unknown" >
      ${status.map((e) => e.toString()).join()}
    </ziStatus>
    '''
        .trimer;
  }
}

==> 0.0.61.tar.gz: lib/classes/Devices/zi_device.dart <==
import '../../artemis_cupps.dart';
import '../../classes/device.dart';
import 'package:xml/xml.dart';
import '../classes.dart';

class ZiDevice extends Device {
  ZiDevice(
      {required ZiDeviceParameter deviceParameter,
      required String deviceIndex,
      required String deviceName,
      required String deviceParameterType,
      required List<InterfaceMode> supportedInterfaceModes,
      required List<Device> devices})
      : super(
            deviceParameter: deviceParameter,
            devices: devices,
            deviceParameterType: deviceParameterType,
            deviceName: deviceName,
            deviceIndex: deviceIndex,
            supportedInterfaceModes: supportedInterfaceModes,
      socketService: SocketService(ip: deviceParameter.ipAndPort.ip, port: int.tryParse(deviceParameter.ipAndPort.port)??0));

  factory ZiDevice.fromDevice(Device d) {
    return ZiDevice(
      deviceParameter: ZiDeviceParameter.fromXML(d.deviceParameter.toXML()),
      deviceIndex: d.deviceIndex,
      deviceName: d.deviceName,
      deviceParameterType: d.deviceParameterType,
      supportedInterfaceModes: d.supportedInterfaceModes,
      devices: d.devices,
    );
  }
}

class ZiDeviceParameter extends DeviceParameter {
  ZiDeviceParameter({
    required VendorModelInfo vendorModelInfo,
    required IpAndPort ipAndPort,
    required Status status,
  }) : super(
            vendorModelInfo: vendorModelInfo,
            ipAndPort: ipAndPort,
            status: status);

  factory ZiDeviceParameter.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);

    XmlElement? vendorModelInfoElement =
        document.firstChild!.getElement("vendorModelInfo");
    XmlElement? ipAndPortElement = document.firstChild!.getElement("ipAndPort");
    XmlElement? statusElement = document.firstChild!.getElement("ziStatus");

    VendorModelInfo vendorModelInfo = vendorModelInfoElement == null
        ? VendorModelInfo(vendor: '', model: '', miscInfo: '')
        : VendorModelInfo.fromXML(vendorModelInfoElement.toXmlString());

    IpAndPort ipAndPort = IpAndPort.fromXML(ipAndPortElement!.toXmlString());
    ZiStatus status = ZiStatus.fromXML(statusElement!.toXmlString());
    return ZiDeviceParameter(
      vendorModelInfo: vendorModelInfo,
      ipAndPort: ipAndPort,
      status: status,
    );
  }

  @override
  String toXML() {
    return '''<ziDeviceParameter>
    ${ipAndPort.toXML()}
    ${status.toXML()}
    </ziDeviceParameter>
    ''';
  }
}

class ZiStatus extends Status {
  final List<Status> status;

  ZiStatus(
      {required String desc,
      required String init,
      required String ready,
      required String unknown,
      required this.status})
      : super(
            desc: desc,
            init: init,
            powerOff: "",
            ready: ready,
            unknown: unknown);

  factory ZiStatus.fromXML(String xmlSTR) {
    final document = XmlDocument.parse(xmlSTR);
    String desc = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "desc",
            orElse: orElseEmpty)
        .value;
    String init = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "init")
        .value;
    String ready = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "ready")
        .value;
    String unknown = document.firstChild!.attributes
        .firstWhere((element) => element.name.toString() == "unknown")
        .value;
    List<Status> status = [];
    return ZiStatus(
        desc: desc, init: init, ready: ready, unknown: unknown, status: status);
  }

  @override
  String toXML() {
    return '''
    <ziStatus desc="$desc" init="$init" ready="$ready" unknown="$unknown" >
    ${status.map((e) => e.toString()).join()}
    </ziStatus>
    ''';
  }
}
